==> apache-asterixdb-0.9.1-source-release.zip: apache-asterixdb-0.9.1/asterix-app/src/main/java/org/apache/asterix/app/nc/task/BindMetadataNodeTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.app.nc.task;

import org.apache.asterix.common.api.IAppRuntimeContext;
import org.apache.asterix.common.api.INCLifecycleTask;
import org.apache.hyracks.api.exceptions.HyracksDataException;
import org.apache.hyracks.api.service.IControllerService;

public class BindMetadataNodeTask implements INCLifecycleTask {

    private static final long serialVersionUID = 1L;
    private final boolean exportStub;

    public BindMetadataNodeTask(boolean exportStub) {
        this.exportStub = exportStub;
    }

    @Override
    public void perform(IControllerService cs) throws HyracksDataException {
        IAppRuntimeContext appContext = (IAppRuntimeContext) cs.getApplicationContext();
        try {
            if (exportStub) {
                appContext.exportMetadataNodeStub();
            } else {
                appContext.unexportMetadataNodeStub();
            }
        } catch (Exception e) {
            throw HyracksDataException.create(e);
        }
    }
}

==> apache-asterixdb-0.9.2-source-release.zip: apache-asterixdb-0.9.2/asterix-app/src/main/java/org/apache/asterix/app/nc/task/BindMetadataNodeTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.app.nc.task;

import org.apache.asterix.common.api.INcApplicationContext;
import org.apache.asterix.common.api.INCLifecycleTask;
import org.apache.hyracks.api.exceptions.HyracksDataException;
import org.apache.hyracks.api.service.IControllerService;

public class BindMetadataNodeTask implements INCLifecycleTask {

    private static final long serialVersionUID = 1L;
    private final boolean exportStub;

    public BindMetadataNodeTask(boolean exportStub) {
        this.exportStub = exportStub;
    }

    @Override
    public void perform(IControllerService cs) throws HyracksDataException {
        INcApplicationContext appContext = (INcApplicationContext) cs.getApplicationContext();
        try {
            if (exportStub) {
                appContext.exportMetadataNodeStub();
            } else {
                appContext.unexportMetadataNodeStub();
            }
        } catch (Exception e) {
            throw HyracksDataException.create(e);
        }
    }
}
